summaryrefslogtreecommitdiffstats
path: root/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/wizards/newaccountwizard/knewaccountwizard.h')
-rw-r--r--kmymoney2/wizards/newaccountwizard/knewaccountwizard.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h b/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
index 158df41..c288d11 100644
--- a/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
+++ b/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
@@ -69,7 +69,7 @@ class Wizard : public KMyMoneyWizard
Q_OBJECT
TQ_OBJECT
public:
- Wizard(TQWidget* tqparent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
+ Wizard(TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
/**
* Returns the information about the account as entered by
@@ -83,10 +83,10 @@ public:
void setAccount(const MyMoneyAccount& acc);
/**
* Returns the information about the tqparent account as entered by
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
* user selected tqparent accounts later.
*/
const MyMoneyAccount& parentAccount(void);
@@ -83,10 +83,10 @@ public:
void setAccount(const MyMoneyAccount& acc);
/**
- * Returns the information about the tqparent account as entered by
+ * Returns the information about the parent account as entered by
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
@@ -83,10 +83,10 @@ public:
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
- * user selected tqparent accounts later.
+ * user selected parent accounts later.
*/
const MyMoneyAccount& parentAccount(void);